@@ -128,7 +128,11 @@ class Component:
         parent_frame=None
     ):
         self.parent = parent
-        self.parent_frame = parent_frame if parent_frame else parent.tkinter
+        if parent_frame is not None:
+            p = parent_frame
+        else:
+            p = parent.tkinter
+        self.parent_frame = p
         self.tkinter = None
         self.vars = []
         if not isinstance(fill, dict):
